@@ -19,7 +19,7 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.29.5"
+VERSION    = "2.29.92"
 LOCALEDIR  = "/usr/local/share/locale"
 DATADIR    = "/usr/local/share"
 SYSCONFDIR = "/usr/local/etc"
@@ -47,6 +47,18 @@ XEPHYR_USR1_TIMEOUT = 10
 #
 PROTOTYPE_USER = "sabayon"
 
+#
+# default, mandatory, and mandatory-alt gconf key trees in users
+# home directory.
+#
+
+GCONF_DEFAULTS_SOURCE      = ".gconf.xml.defaults"
+GCONF_MANDATORY_SOURCE     = ".gconf.xml.mandatory"
+GCONF_MANDATORY_ALT_SOURCE = ".gconf.xml.mandatory-alt"
+
+GCONF_PATH_DEFAULTS        = ".gconf.path.defaults"
+GCONF_PATH_MANDATORY       = ".gconf.path.mandatory"
+
 # FIXME: should all of these be options passed to the "configure" script?
 DEFAULT_PATH  = "/usr/local/bin:/usr/bin:/bin:/usr/X11R6/bin"
 DEFAULT_SHELL = "/bin/bash"
@@ -84,51 +96,26 @@ PASSTHROUGH_ENVIRONMENT = [
 # Files which we don't want to see change notifications for
 #
 FILES_TO_IGNORE = [
+    GCONF_PATH_DEFAULTS,
+    GCONF_PATH_DEFAULTS + ".new",
+    GCONF_PATH_MANDATORY,
+    GCONF_PATH_MANDATORY + ".new",
     ".ICEauthority*",
     ".esd_auth",
     ".fonts.cache-1*",
-    ".gconf.path.defaults",
-    ".gconf.path.defaults.new",
-    ".gconf.path.mandatory",
-    ".gconf.path.mandatory.new",
     ".gnome/gnome-vfs/.trash_entry_cache",
     ".gnome2/share/cursor-fonts/fonts.dir",
     ".gnome2/share/fonts/fonts.dir",
     ".gtkrc-1.2-gnome2*",
     ".pulse-cookie",
     ".recently-used*",
-    ".xsession-errors"
-]
-
-#
-# Directories which we don't want to see change notifications for
-# 
-DIRECTORIES_TO_IGNORE = [
-    ".beagle",
-    ".cache",
-    ".ccache",
-    ".dbus",
-    ".fontconfig",
-    ".gconf",
-    ".gconf.xml.defaults",
-    ".gconf.xml.mandatory",
-    ".gconf.xml.mandatory-alt",
-    ".gconfd",
-    ".gstreamer-0.8",
-    ".gstreamer-0.10",
-    ".gvfs",
-    ".local/share/tracker",
-    ".metacity/sessions",
-    ".profile_cache",
-    ".pulse",
-    ".thumbnails",
-    ".wapi",
-    ".Trash"
+    ".xsession-errors",
+    ".imsettings.log"
 ]
 
 #
 # Directories which we don't want to add when saving profile
-# 
+#
 DIRECTORIES_TO_IGNORE_PROFILE = [
     ".beagle",
     ".cache",
@@ -145,7 +132,19 @@ DIRECTORIES_TO_IGNORE_PROFILE = [
     ".pulse",
     ".thumbnails",
     ".wapi",
-    ".Trash"
+    ".Trash",
+    ".evolution/cache",
+    ".local/share/gvfs-metadata"
+]
+
+#
+# Directories which we don't want to see change notifications for
+#
+DIRECTORIES_TO_IGNORE = DIRECTORIES_TO_IGNORE_PROFILE + [
+    ".gconf",
+    GCONF_DEFAULTS_SOURCE,
+    GCONF_MANDATORY_SOURCE,
+    GCONF_MANDATORY_ALT_SOURCE
 ]
 
 #
